"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const fs = require("fs");
const logger_1 = require("./logger");
// tslint:disable-next-line:no-unnecessary-class
class Utilities {
    static getStringFromFile(thisRef, filePath) {
        let fileStr = '';
        if (!fs.existsSync(filePath)) {
            logger_1.default.error(thisRef, `Could not find file: ${chalk.red(filePath)}`); // this will output error and exit command
        }
        else {
            let fileBuffer = fs.readFileSync(filePath);
            fileStr = fileBuffer.toString(); // by default utf8
        }
        return fileStr;
    }
    static getJsonObjectFromFile(thisRef, filePath) {
        if (!fs.existsSync(filePath)) {
            logger_1.default.error(thisRef, `Could not find file: ${chalk.red(filePath)}`); // this will output error and exit command
        }
        else {
            let jsonString = fs.readFileSync(filePath, 'utf8');
            try {
                return JSON.parse(jsonString);
            }
            catch (err) {
                logger_1.default.error(this, 'Error parsing JSON string:' + err);
            }
        }
    }
    static getInputString(thisRef, flags, args) {
        // if -s or -f is not passed we will take it from args
        if (flags.string) //if -s given
            return flags.string;
        else if (flags.file) { // if -f given
            logger_1.default.info(thisRef, `reading file: ${chalk.green(flags.file)}`);
            return Utilities.getStringFromFile(thisRef, flags.file);
        }
        else
            return args.string;
    }
    static writeStringToFile(thisRef, filePath, string) {
        if (!fs.existsSync(filePath))
            logger_1.default.info(thisRef, `Could not find file: ${chalk.yellow(filePath + ', creating new one')}`); // this will output error and exit command
        else
            logger_1.default.warn(thisRef, `File already exists: ${chalk.green(filePath)}, ${chalk.yellow('overriding content')}`); // this will output error and exit command
        fs.writeFileSync(filePath, string);
        if (string !== '') // this condition comes for truncating
            logger_1.default.success(thisRef, `output written to file: ${chalk.green(filePath)}`); // this will output error and exit command
        // return `${chalk.red(pkg)} ${message}`
    }
    static appendStringToFile(thisRef, filePath, string) {
        if (!fs.existsSync(filePath))
            logger_1.default.info(thisRef, `Could not find file: ${chalk.yellow(filePath + ', creating new one')}`); // this will output error and exit command
        fs.appendFileSync(filePath, string);
    }
    static truncateFile(thisRef, filePath) {
        // if (fs.existsSync(filePath))
        //   Logger.info(thisRef, `file found: ${chalk.yellow(filePath + ', truncating')}`) // this will output error and exit command
        Utilities.writeStringToFile(thisRef, filePath, ''); // write nothing
    }
}
exports.default = Utilities;
//# sourceMappingURL=utilities.js.map